<?php

/*
Page Manager Plugin for MyBB
Copyright (C) 2014 Daniel Hewes http://www.silvertails.net

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
// Disallow direct access to this file for security reasons
if(!defined("IN_MYBB"))
{
    die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

$plugins->add_hook('admin_user_action_handler','randomuser_admin_action');
$plugins->add_hook('admin_user_menu','randomuser_admin_menu');
//$plugins->add_hook('admin_config_permissions','pagemanager_admin_permissions');
$plugins->add_hook('admin_load','randomuser_admin');

function randomuser_info()
{
	return array(
        "name"          => "Random Admin User Generator",
        "description"   => "Generates a Random Username from a specified Group",
        "website"       => "http://silvertails.net",
        "author"        => "Daniel Hewes",
        "authorsite"    => "mailto:Daniel.Hewes@gmail.com",
        "version"       => "0.1",
        "compatibility" => "16*",
        "guid"        => '9195781238f0e25f010ca5de8a0b368f'
        );
}

function randomuser_activate()
{
	//Do Nothing
}

function randomuser_deactivate()
{
	//Do nothing
}

function randomuser_install()
{
	//nothing to do - simple plugin
}

function randomuser_is_installed()
{
	//again nothing to do or display
}

function randomuser_uninstall()
{
	//nothing to do as it just adds functionality
}



function randomuser_admin_action(&$action)
{
	$action['randomuser']=array('active'=>'randomuser');
}

function randomuser_admin_menu(&$sub_menu)
{
	
	end($sub_menu);
	$key=(key($sub_menu))+10;
	$sub_menu[$key]=array
	(
		'id'=>'randomuser',
		'title'=>"Random User",
		'link'=>'index.php?module=user-randomuser'
	);
}

function randomuser_admin()
{
	global $db, $lang, $config, $mybb, $page;
	
	//Make sure that we are in the correct admin area
	if($page->active_action!='randomuser')
	{
		return false;
	}
	
	// Build the start of the page
	$page->add_breadcrumb_item("Random User", "index.php?module=user-random");
	$page->output_header("Generate a Random user");
	
	
	//If the form has been submitted lets perform our actions and Get us a user
	if($mybb->input['paction']=='randomize')
	{
		//initialize a tabl object
		$table = new Table;
		
		//Since we use this twice we may as well put this in a sanitized variable
		$search_usergroup = intval($mybb->input['usergroup']);

		//mysql is not truly random so we will do the "best case" scenario and use a timestamp on the rand()
		$query = $db->write_query("Select uid, username from ".TABLE_PREFIX."users where usergroup=".$search_usergroup." OR ".$search_usergroup." IN (additionalgroups) ORDER BY RAND(UNIX_TIMESTAMP()) LIMIT 1");
			
		//Lets get that sucker into an array and display it
		while($result=$db->fetch_array($query))
		{
			$table->construct_cell(build_profile_link($result['username'], $result['uid']));
			
			$table->construct_row();	
			
			//Lets log the entry in the adminlogs
			randuser_log_entry($result['username']);

		}
		//Free the result set
		$db->free_result($query);
		$table->output("Your Randomly Generated User");
	}
	
	//No point ever hiding the form as you may want to re-use it and generate a new user, lets display it whether there is already a result or no
	
	//create a new form handler
	$form = new Form("index.php?module=user-randomuser&amp;paction=randomize", "post");
	$form_container = new FormContainer("Random User Generator");

	//get the list of user groups to select from
	$query = $db->simple_select("usergroups", "gid, title", "gid != '1'", array('order_by' => 'title'));
	while($usergroup = $db->fetch_array($query))
	{
		$options[$usergroup['gid']] = $usergroup['title'];
		$display_group_options[$usergroup['gid']] = $usergroup['title'];
		
	}


	$form_container->output_row("Select the group you wish to generate a user from, both additional usergroups and primary group will be searched <em>*</em>", "", $form->generate_select_box('usergroup', $options, $mybb->input['usergroup'], array('id' => 'usergroup')), 'usergroup');

	$form_container->end();
	$buttons[] = $form->generate_submit_button("Generate Random User");
	$form->output_submit_wrapper($buttons);

	$form->end();
	
	echo '
		<br />
		<fieldset>
	<legend>Brought to You by</legend>
	<a href="http://www.silvertails.net">Silvertails.net</a>
	<form action="https://www.paypal.com/cgi-bin/webscr" method="post" target="_top">
<input type="hidden" name="cmd" value="_donations">
<input type="hidden" name="business" value="daniel.hewes@gmail.com">
<input type="hidden" name="lc" value="US">
<input type="hidden" name="item_name" value="silvertails.net">
<input type="hidden" name="no_note" value="0">
<input type="hidden" name="currency_code" value="USD">
<input type="hidden" name="bn" value="PP-DonationsBF:btn_donate_SM.gif:NonHostedGuest">
<input type="image" src="https://www.paypalobjects.com/en_US/i/btn/btn_donate_SM.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
<img alt="" border="0" src="https://www.paypalobjects.com/en_US/i/scr/pixel.gif" width="1" height="1">
</form>


	</fieldset>
	';
	$page->output_footer();
}

function randuser_log_entry($user)
{
	global $db, $mybb;
	$admin_log_entry = array(
			'uid' => $mybb->user['uid'],
			'ipaddress' => $db->escape_string(get_ip()),
			'dateline' => TIME_NOW,
			'module' => 'Random User',
			'action' => $db->escape_string('Randomly selected <b>'.$user.'</b>'),
			'data' => 'a:0:{}' 
		);

	$db->insert_query('adminlog', $admin_log_entry);
}	
?>